SIMPLE_ANIMAL_DEFINITIONS["running_knuckles"] = {
	--Base animations--
  ["goal"] = {H},
--[TRICK_BEHIND] = {A-E}, -- Acrobatics plays "A-E" as the rotations for afterimages that play after you've tricked so I'm gonna leave them blank.
--[CHARACTER_SELECT] = {G}, -- G and J get used for the character select animation.  
  ["stand"] = {J},
  ["walk"] = {K, L, M, N, O, P, Q, R},
  ["run"] = {S, T, U, V},
  ["reverse"] = {R, Q, P, O, N, M, L, K},
  ["trick"] = {W, X, Y, Z, Z+1, Z+2},
  ["spin"] = {I},
  ["pain"] = {Z+11},
  ["squish"] = {Z+10},
  ["ascend"] = {Z+7},
  ["descend"] = {Z+8, Z+8, Z+9, Z+9},
  ["glide"] = {F},  
  ["finished"] = {J},
  ["drift"] = {Z+3, Z+4, Z+5, Z+6},
------------------------------------------------------------------------------------------------------------------
  ["knuckleswalk"] = {K, L, M, N, O, P, Q, R},
  ["knucklesrun"] = {S, T, U, V},
  ["roll"] = {W, X, Y, Z, Z+1, Z+2},
  ["win"] = {Z+12, Z+12, Z+12, Z+12, Z+12, Z+12, Z+12, Z+12,
                  Z+13, Z+13, Z+13, Z+13, Z+13, Z+13, Z+13, Z+13},
  ["lose"] = {Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14, Z+14,
              Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15, Z+15}
 
}

			--Character Specific--

function SIMPLE_ANIMAL_HELPERS.isKnucklesRunSpeed(mobj) -- Checks if the player is at Knuckles's running speed.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return player.speed > mobj.scale * 40 and player.speed <= mobj.scale * 50
end

function SIMPLE_ANIMAL_HELPERS.isKnucklesTopSpeed(mobj) -- Checks if the player is at Knuckles's top speed.
  return SIMPLE_ANIMAL_HELPERS.getPlayer(mobj).speed > mobj.scale * 50
end

function SIMPLE_ANIMAL_HELPERS.isKnucklesWalkSpeed(mobj) -- Checks if the player is at Knuckles's walking speed, but not Knuckles's running speed.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return player.speed > 0 and player.speed <= mobj.scale * 40
end

function SIMPLE_ANIMAL_HELPERS.isKnucklesWalkSpeedMultiplied(mobj, fixed_multiplier) -- Checks if the player's speed is >= Knuckles's walking speed multiplied (using fixed-point math.)
  local run = (mobj.scale * 40)
  return SIMPLE_ANIMAL_HELPERS.getPlayer(mobj).speed >= FixedMul(run, fixed_multiplier)
end

			--Other added helpers--

function SIMPLE_ANIMAL_HELPERS.isGliding(mobj)
  return mobj.paragliding
end

function SIMPLE_ANIMAL_HELPERS.isGrinding(mobj) -- Checks if the player is on grind rail.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return (player.grinding)
end

function SIMPLE_ANIMAL_HELPERS.isSpinDashing(mobj) -- Checks if the player is spindashing.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return player.spindash and player.spindash.active
end

function SIMPLE_ANIMAL_HELPERS.isScending(mobj) -- Checks if the player is nor rising or falling through the air.
  return mobj.momz > 0 and mobj.momz < 250000 and not P_IsObjectOnGround(mobj)
end

function SIMPLE_ANIMAL_HELPERS.isSuper(mobj) -- Checks if the player is super.
  return SIMPLE_ANIMAL_HELPERS.getPlayer(mobj).masteremerald.super
end

function SIMPLE_ANIMAL_HELPERS.isLose(mobj) -- Checks if the player is losing.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  if player then
    return K_IsPlayerLosing(player)
  else
    return false
  end
end

function SIMPLE_ANIMAL_HELPERS.isWin(mobj) -- Checks if the player is winning.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  if player then
    return not K_IsPlayerLosing(player)
  else
    return false
  end
end

function SIMPLE_ANIMAL_HELPERS.isSpringingDown(mobj) -- Checks if the player is falling through the air after bouncing off a spring.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return mobj.momz <= 0 and not P_IsObjectOnGround(mobj) and player.sprung == true
end

-- the regular isSpringing function is for spring pads or the pogospring item

function SIMPLE_ANIMAL_HELPERS.isSpringingUp(mobj) -- Checks if the player is falling through the air after bouncing off a spring.
  local player = SIMPLE_ANIMAL_HELPERS.getPlayer(mobj)
  return mobj.momz >= 0 and player.sprung == true
end
				--Rest of Code--

function SIMPLE_ANIMAL_HOOKS.running_knuckles_hook(mobj, sequences)
  if mobj.skin == "running_knuckles"
    local helpers = _G["SIMPLE_ANIMAL_HELPERS"]
	
	  local halfspeed = helpers.isKnucklesWalkSpeedMultiplied(mobj, FRACUNIT/2)
	  local quarterspeed = helpers.isKnucklesWalkSpeedMultiplied(mobj, FRACUNIT/4)
    if (sequences[1] == "goal")
      return
	elseif helpers.isSquished(mobj)
	  return "squish"
	elseif helpers.isPained(mobj)
	  return "pain"
	elseif helpers.isSpinning(mobj)
	  return "spin"
	elseif (helpers.isTricking(mobj) or helpers.isDropDashing(mobj) or helpers.isRespawning(mobj))
	  return "trick"
	elseif helpers.isGliding(mobj)
	  return "glide"
	elseif (helpers.isGrinding(mobj) or helpers.isScending(mobj))
	  return "roll"
    elseif helpers.isAscending(mobj)
      return "ascend"
    elseif helpers.isDescending(mobj)
      return "descend"
	elseif (helpers.isCountdownCharging(mobj) or helpers.isDriftingLeft(mobj) or helpers.isDriftingRight(mobj))
      return "drift"
	elseif (helpers.isKnucklesRunSpeed(mobj) or helpers.isKnucklesTopSpeed(mobj))
	  return "knucklesrun"
    elseif helpers.isFinished(mobj) and helpers.isNoSpeed(mobj)
		if helpers.isLose(mobj)
      return "lose"
		elseif helpers.isWin(mobj)
	  return "win"
		else
	  return "stand"
		end
elseif helpers.isKnucklesWalkSpeed(mobj) and not (helpers.isDriftingLeft(mobj) or helpers.isDriftingRight(mobj) or helpers.isPained(mobj) or helpers.isAirborne(mobj)) then
    if helpers.isMovingForward(mobj) then
        if ((not quarterspeed and leveltime % 4 < 3) or (quarterspeed and not halfspeed) and leveltime % 2 < 1) then
            mobj.Simple_AnimaL_timer = mobj.Simple_AnimaL_timer - 1
        end
        return "knuckleswalk"
    elseif helpers.isMovingBackward(mobj) then
        if ((not quarterspeed and leveltime % 4 < 3) or (quarterspeed and not halfspeed) and leveltime % 2 < 1) then
            mobj.Simple_AnimaL_timer = mobj.Simple_AnimaL_timer - 1
        end
        return "reverse"
    end
		end
	end
end